@@ -1,7 +1,7 @@
 """ladybug-pandas library."""
 
-from .dataframe import dataframe_from_collections, dataframe_from_epw
-from .series import series_from_collection
+from .dataframe import DataFrame
+from .series import Series
 
 from .accessors.ladybug import LadybugSeriesAccessor, LadybugDataFrameAccessor
 from .accessors.psychrometrics import PsychrometricsAccessor
\ No newline at end of file
